@@ -20,6 +20,7 @@
 #define MULTI_TRACK_READER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -38,7 +39,7 @@ namespace Kwave
      * A MultiTrackReader encapsulates a set of <c>SampleReader</c>s for
      * easier use of multi-track signals.
      */
-    class Q_DECL_EXPORT MultiTrackReader
+    class LIBKWAVE_EXPORT MultiTrackReader
         :public Kwave::MultiTrackSource<Kwave::SampleReader, false>
     {
         Q_OBJECT
@@ -63,7 +64,7 @@ namespace Kwave
                         sample_index_t first, sample_index_t last);
 
         /** Destructor */
-        virtual ~MultiTrackReader() Q_DECL_OVERRIDE;
+        ~MultiTrackReader() override;
 
         /**
          * Returns the offset of the reader, as
@@ -88,7 +89,7 @@ namespace Kwave
 
         /** @see QList::insert() */
         virtual bool insert(unsigned int track, Kwave::SampleReader *reader)
-            Q_DECL_OVERRIDE;
+            override;
 
         /** Skips a number of samples. */
         virtual void skip(sample_index_t count);
