@@ -39,10 +39,10 @@ namespace Kwave
         AsciiEncoder();
 
         /** Destructor */
-        virtual ~AsciiEncoder() Q_DECL_OVERRIDE;
+        ~AsciiEncoder() override;
 
         /** Returns a new instance of the encoder */
-        virtual Kwave::Encoder *instance() Q_DECL_OVERRIDE;
+        Kwave::Encoder *instance() override;
 
         /**
          * Encodes a signal into a stream of bytes.
@@ -56,11 +56,11 @@ namespace Kwave
         virtual bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
                             QIODevice &dst,
                             const Kwave::MetaDataList &meta_data)
-            Q_DECL_OVERRIDE;
+            override;
 
         /** Returns a list of supported file properties */
         virtual QList<Kwave::FileProperty> supportedProperties()
-            Q_DECL_OVERRIDE;
+            override;
 
     private:
 
