@@ -66,7 +66,7 @@ QStringList *Kwave::GotoPluginBase::setup(QStringList &previous_params)
             m_mode, m_position, rate, length, help_section
         );
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     // set the title of the dialog, depending on the derived class
     dialog->setWindowTitle(title());
@@ -85,8 +85,8 @@ QStringList *Kwave::GotoPluginBase::setup(QStringList &previous_params)
         );
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
     delete dialog;
@@ -150,3 +150,5 @@ int Kwave::GotoPluginBase::interpreteParameters(QStringList &params)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_GotoPluginBase.cpp"
